@@ -10,7 +10,7 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume, \
-    StorageConfigurationLinuxVolume, MountedVolume, LinuxDevice, TemplateConfigurationLinuxVolume
+    StorageConfigurationDrive, MountedVolume, LinuxDevice, TemplateConfigurationDrive
 from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
@@ -89,7 +89,7 @@ class LVMTemplateForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = StorageConfigurationLinuxVolume
+        model = StorageConfigurationDrive
         exclude = (
             "cluster_type",
             "vg_name",
@@ -192,7 +192,7 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = TemplateConfigurationLinuxVolume
+        model = TemplateConfigurationDrive
         fields = [
             "platform",
         ]
@@ -259,7 +259,7 @@ class DriveTemplateForm(NetBoxModelForm):
     )
 
     class Meta:
-        model = TemplateConfigurationLinuxVolume
+        model = TemplateConfigurationDrive
         fields = [
             "platform",
         ]
@@ -350,7 +350,7 @@ class PartitionTemplateForm(NetBoxModelForm):
         device_name_prefix = Drive.objects.get(pk=self.cleaned_data['drive'].id).device_name()
         print(f"Partition Count: {new_partition_count}")
         print(f"Device Name: {device_name_prefix}")
-        device_name = device_name_prefix + new_partition_count
+        device_name = device_name_prefix + str(new_partition_count)
 
         linux_device = LinuxDevice.objects.create(device=device_name, type='efi')
 
