@@ -207,7 +207,7 @@ class Migration(migrations.Migration):
             },
         ),
         migrations.CreateModel(
-            name="StorageConfigurationLinuxVolume",
+            name="StorageConfigurationDrive",
             fields=[
                 ("created", models.DateTimeField(auto_now_add=True, null=True)),
                 ("last_updated", models.DateTimeField(auto_now=True, null=True)),
@@ -224,14 +224,14 @@ class Migration(migrations.Migration):
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
                                    related_name="virtual_machine_storage_configuration",
                                    to="virtualization.virtualmachine")),
-                ("linux_volume",
+                ("drive",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
-                                   related_name='linux_volume_storage_configuration',
-                                   to='netbox_storage.mountedvolume')),
+                                   related_name='drive_storage_configuration',
+                                   to='netbox_storage.drive')),
             ],
         ),
         migrations.CreateModel(
-            name="TemplateConfigurationLinuxVolume",
+            name="TemplateConfigurationDrive",
             fields=[
                 ("created", models.DateTimeField(auto_now_add=True, null=True)),
                 ("last_updated", models.DateTimeField(auto_now=True, null=True)),
