@@ -1,4 +1,3 @@
-from django.core.exceptions import ValidationError
 from django.db import models
 from django.db.models import Sum
 from django.urls import reverse
@@ -349,25 +348,25 @@ class MountedVolume(NetBoxModel):
         ordering = ("device", "mount_point", "fs_type", "options", "description")
 
 
-class StorageConfigurationLinuxVolume(NetBoxModel):
+class StorageConfigurationDrive(NetBoxModel):
     virtual_machine = models.ForeignKey(
         to='virtualization.VirtualMachine',
         on_delete=models.CASCADE,
         related_name='virtual_machine_storage_configuration',
     )
-    linux_volume = models.ForeignKey(
-        MountedVolume,
+    drive = models.ForeignKey(
+        Drive,
         on_delete=models.CASCADE,
-        related_name='linux_volume_storage_configuration'
+        related_name='drive_storage_configuration'
     )
 
     clone_fields = [
         "virtual_machine",
-        "linux_volume"
+        "drive"
     ]
 
     class Meta:
-        ordering = ["virtual_machine", "linux_volume"]
+        ordering = ["virtual_machine", "drive"]
 
     #def get_absolute_url(self):
     #    return reverse("plugins:netbox_storage:storageconfiguration", kwargs={"pk": self.pk})
@@ -376,7 +375,7 @@ class StorageConfigurationLinuxVolume(NetBoxModel):
         return f"Storage Configuration of the VM {self.virtual_machine}"
 
 
-class TemplateConfigurationLinuxVolume(NetBoxModel):
+class TemplateConfigurationDrive(NetBoxModel):
     platform = models.ForeignKey(
         to='dcim.platform',
         on_delete=models.CASCADE,
